@@ -1,6 +1,6 @@
 package ZMQ::FFI;
 {
-  $ZMQ::FFI::VERSION = '0.07';
+  $ZMQ::FFI::VERSION = '0.08';
 }
 # ABSTRACT: zeromq bindings using libffi and FFI::Raw
 
@@ -44,7 +44,7 @@ ZMQ::FFI - zeromq bindings using libffi and FFI::Raw
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ version 0.07
 
     use v5.10;
     use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_REQ ZMQ_REP ZMQ_DONTWAIT);
+    use ZMQ::FFI::Constants qw(ZMQ_REQ ZMQ_REP);
 
     my $endpoint = "ipc://zmq-ffi-$$";
     my $ctx      = ZMQ::FFI->new( threads => 1 );
@@ -63,7 +63,7 @@ version 0.07
     my $s2 = $ctx->socket(ZMQ_REP);
     $s2->bind($endpoint);
 
-    $s1->send('ohhai', ZMQ_DONTWAIT);
+    $s1->send('ohhai');
 
     say $s2->recv();
     # ohhai
@@ -73,7 +73,7 @@ version 0.07
 
     use v5.10;
     use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_PUB ZMQ_SUB ZMQ_DONTWAIT);
+    use ZMQ::FFI::Constants qw(ZMQ_PUB ZMQ_SUB);
     use Time::HiRes q(usleep);
 
     my $endpoint = "ipc://zmq-ffi-$$";
@@ -88,12 +88,12 @@ version 0.07
     # all topics
     {
         $s->subscribe('');
-        $p->send('ohhai', ZMQ_DONTWAIT);
+        $p->send('ohhai');
 
         until ($s->has_pollin) {
             # compensate for slow subscriber
             usleep 100_000;
-            $p->send('ohhai', ZMQ_DONTWAIT);
+            $p->send('ohhai');
         }
 
         say $s->recv();
@@ -107,13 +107,13 @@ version 0.07
         $s->subscribe('topic1');
         $s->subscribe('topic2');
 
-        $p->send('topic1 ohhai', ZMQ_DONTWAIT);
-        $p->send('topic2 ohhai', ZMQ_DONTWAIT);
+        $p->send('topic1 ohhai');
+        $p->send('topic2 ohhai');
 
         until ($s->has_pollin) {
             usleep 100_000;
-            $p->send('topic1 ohhai', ZMQ_DONTWAIT);
-            $p->send('topic2 ohhai', ZMQ_DONTWAIT);
+            $p->send('topic1 ohhai');
+            $p->send('topic2 ohhai');
         }
 
         while ($s->has_pollin) {
@@ -128,7 +128,7 @@ version 0.07
 
     use v5.10;
     use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_DEALER ZMQ_ROUTER ZMQ_DONTWAIT);
+    use ZMQ::FFI::Constants qw(ZMQ_DEALER ZMQ_ROUTER);
 
     my $endpoint = "ipc://zmq-ffi-$$";
     my $ctx      = ZMQ::FFI->new();
@@ -141,7 +141,7 @@ version 0.07
     $d->connect($endpoint);
     $r->bind($endpoint);
 
-    $d->send_multipart([qw(ABC DEF GHI)], ZMQ_DONTWAIT);
+    $d->send_multipart([qw(ABC DEF GHI)]);
 
     say join ' ', $r->recv_multipart;
     # dealer ABC DEF GHI
@@ -324,7 +324,7 @@ remove C<$topic> from the subscription list
 
 =head2 send($msg, [$flags])
 
-    $socket->send('ohhai', ZMQ_DONTWAIT)
+    $socket->send('ohhai')
 
 sends a message using the optional flags
 
@@ -388,6 +388,10 @@ L<ZMQ::FFI::Constants>
 
 L<ZMQ::FFI::Util>
 
+=item *
+
+L<FFI::Raw>
+
 =back
 
 =head1 AUTHOR
@@ -396,7 +400,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Dylan Cali.
+This software is copyright (c) 2014 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
