@@ -1,18 +1,24 @@
 package ZMQ::FFI::Constants;
 {
-  $ZMQ::FFI::Constants::VERSION = '0.07';
+  $ZMQ::FFI::Constants::VERSION = '0.08';
 }
 
 # ABSTRACT: Generated module of zmq constants. All constants, all versions.
 
-# Module generated on Wed Oct  2 06:46:29 2013
-# Generated using ZMQ versions v2.1.0-v3.2.4
+# Module generated on Thu Jan 16 06:27:50 2014
+# Generated using ZMQ versions v2.1.0-v4.0.3
 
 use Exporter 'import';
 
 @EXPORT_OK = qw(
 ZMQ_AFFINITY
 ZMQ_BACKLOG
+ZMQ_CONFLATE
+ZMQ_CURVE
+ZMQ_CURVE_PUBLICKEY
+ZMQ_CURVE_SECRETKEY
+ZMQ_CURVE_SERVER
+ZMQ_CURVE_SERVERKEY
 ZMQ_DEALER
 ZMQ_DELAY_ATTACH_ON_CONNECT
 ZMQ_DELIMITER
@@ -28,15 +34,18 @@ ZMQ_EVENT_CONNECT_DELAYED
 ZMQ_EVENT_CONNECT_RETRIED
 ZMQ_EVENT_DISCONNECTED
 ZMQ_EVENT_LISTENING
+ZMQ_EVENT_MONITOR_STOPPED
 ZMQ_FAIL_UNROUTABLE
 ZMQ_FD
 ZMQ_FORWARDER
 ZMQ_HAUSNUMERO
 ZMQ_HWM
 ZMQ_IDENTITY
+ZMQ_IMMEDIATE
 ZMQ_IO_THREADS
 ZMQ_IO_THREADS_DFLT
 ZMQ_IPV4ONLY
+ZMQ_IPV6
 ZMQ_LAST_ENDPOINT
 ZMQ_LINGER
 ZMQ_MAXMSGSIZE
@@ -44,16 +53,24 @@ ZMQ_MAX_SOCKETS
 ZMQ_MAX_SOCKETS_DFLT
 ZMQ_MAX_VSM_SIZE
 ZMQ_MCAST_LOOP
+ZMQ_MECHANISM
 ZMQ_MORE
 ZMQ_MSG_MASK
 ZMQ_MSG_MORE
 ZMQ_MSG_SHARED
 ZMQ_MULTICAST_HOPS
 ZMQ_NOBLOCK
+ZMQ_NULL
 ZMQ_PAIR
+ZMQ_PLAIN
+ZMQ_PLAIN_PASSWORD
+ZMQ_PLAIN_SERVER
+ZMQ_PLAIN_USERNAME
 ZMQ_POLLERR
 ZMQ_POLLIN
+ZMQ_POLLITEMS_DFLT
 ZMQ_POLLOUT
+ZMQ_PROBE_ROUTER
 ZMQ_PUB
 ZMQ_PULL
 ZMQ_PUSH
@@ -69,12 +86,16 @@ ZMQ_RECOVERY_IVL
 ZMQ_RECOVERY_IVL_MSEC
 ZMQ_REP
 ZMQ_REQ
+ZMQ_REQ_CORRELATE
+ZMQ_REQ_RELAXED
 ZMQ_ROUTER
 ZMQ_ROUTER_MANDATORY
+ZMQ_ROUTER_RAW
 ZMQ_SNDBUF
 ZMQ_SNDHWM
 ZMQ_SNDMORE
 ZMQ_SNDTIMEO
+ZMQ_STREAM
 ZMQ_STREAMER
 ZMQ_SUB
 ZMQ_SUBSCRIBE
@@ -92,12 +113,19 @@ ZMQ_XPUB_VERBOSE
 ZMQ_XREP
 ZMQ_XREQ
 ZMQ_XSUB
+ZMQ_ZAP_DOMAIN
 );
 
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
 sub ZMQ_AFFINITY { 4 }
 sub ZMQ_BACKLOG { 19 }
+sub ZMQ_CONFLATE { 54 }
+sub ZMQ_CURVE { 2 }
+sub ZMQ_CURVE_PUBLICKEY { 48 }
+sub ZMQ_CURVE_SECRETKEY { 49 }
+sub ZMQ_CURVE_SERVER { 47 }
+sub ZMQ_CURVE_SERVERKEY { 50 }
 sub ZMQ_DEALER { 5 }
 sub ZMQ_DELAY_ATTACH_ON_CONNECT { 39 }
 sub ZMQ_DELIMITER { 31 }
@@ -113,32 +141,43 @@ sub ZMQ_EVENT_CONNECT_DELAYED { 2 }
 sub ZMQ_EVENT_CONNECT_RETRIED { 4 }
 sub ZMQ_EVENT_DISCONNECTED { 512 }
 sub ZMQ_EVENT_LISTENING { 8 }
+sub ZMQ_EVENT_MONITOR_STOPPED { 1024 }
 sub ZMQ_FAIL_UNROUTABLE { 33 }
 sub ZMQ_FD { 14 }
 sub ZMQ_FORWARDER { 2 }
 sub ZMQ_HAUSNUMERO { 156384712 }
 sub ZMQ_HWM { 1 }
 sub ZMQ_IDENTITY { 5 }
+sub ZMQ_IMMEDIATE { 39 }
 sub ZMQ_IO_THREADS { 1 }
 sub ZMQ_IO_THREADS_DFLT { 1 }
 sub ZMQ_IPV4ONLY { 31 }
+sub ZMQ_IPV6 { 42 }
 sub ZMQ_LAST_ENDPOINT { 32 }
 sub ZMQ_LINGER { 17 }
 sub ZMQ_MAXMSGSIZE { 22 }
 sub ZMQ_MAX_SOCKETS { 2 }
-sub ZMQ_MAX_SOCKETS_DFLT { 1024 }
+sub ZMQ_MAX_SOCKETS_DFLT { 1023 }
 sub ZMQ_MAX_VSM_SIZE { 30 }
 sub ZMQ_MCAST_LOOP { 10 }
+sub ZMQ_MECHANISM { 43 }
 sub ZMQ_MORE { 1 }
 sub ZMQ_MSG_MASK { 129 }
 sub ZMQ_MSG_MORE { 1 }
 sub ZMQ_MSG_SHARED { 128 }
 sub ZMQ_MULTICAST_HOPS { 25 }
 sub ZMQ_NOBLOCK { 1 }
+sub ZMQ_NULL { 0 }
 sub ZMQ_PAIR { 0 }
+sub ZMQ_PLAIN { 1 }
+sub ZMQ_PLAIN_PASSWORD { 46 }
+sub ZMQ_PLAIN_SERVER { 44 }
+sub ZMQ_PLAIN_USERNAME { 45 }
 sub ZMQ_POLLERR { 4 }
 sub ZMQ_POLLIN { 1 }
+sub ZMQ_POLLITEMS_DFLT { 16 }
 sub ZMQ_POLLOUT { 2 }
+sub ZMQ_PROBE_ROUTER { 51 }
 sub ZMQ_PUB { 1 }
 sub ZMQ_PULL { 7 }
 sub ZMQ_PUSH { 8 }
@@ -154,12 +193,16 @@ sub ZMQ_RECOVERY_IVL { 9 }
 sub ZMQ_RECOVERY_IVL_MSEC { 20 }
 sub ZMQ_REP { 4 }
 sub ZMQ_REQ { 3 }
+sub ZMQ_REQ_CORRELATE { 52 }
+sub ZMQ_REQ_RELAXED { 53 }
 sub ZMQ_ROUTER { 6 }
 sub ZMQ_ROUTER_MANDATORY { 33 }
+sub ZMQ_ROUTER_RAW { 41 }
 sub ZMQ_SNDBUF { 11 }
 sub ZMQ_SNDHWM { 23 }
 sub ZMQ_SNDMORE { 2 }
 sub ZMQ_SNDTIMEO { 28 }
+sub ZMQ_STREAM { 11 }
 sub ZMQ_STREAMER { 1 }
 sub ZMQ_SUB { 2 }
 sub ZMQ_SUBSCRIBE { 6 }
@@ -177,6 +220,7 @@ sub ZMQ_XPUB_VERBOSE { 40 }
 sub ZMQ_XREP { 6 }
 sub ZMQ_XREQ { 5 }
 sub ZMQ_XSUB { 10 }
+sub ZMQ_ZAP_DOMAIN { 55 }
 
 1;
 
@@ -190,7 +234,7 @@ ZMQ::FFI::Constants - Generated module of zmq constants. All constants, all vers
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -203,8 +247,8 @@ version 0.07
 =head1 DESCRIPTION
 
 This module includes every zmq constant from every stable version of zeromq.
-Currently that is v2.1.0-v3.2.4.  It was generated using the zeromq2-x and
-zeromq3-x git repos at L<https://github.com/zeromq>.
+Currently that is v2.1.0-v4.0.3.  It was generated using the zeromq2-x,
+zeromq3-x, and zeromq4-x git repos at L<https://github.com/zeromq>.
 
 =head1 SEE ALSO
 
@@ -222,7 +266,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Dylan Cali.
+This software is copyright (c) 2014 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
