@@ -1,6 +1,6 @@
 package ZMQ::FFI::ZMQ3::Socket;
 {
-  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.07';
+  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.08';
 }
 
 use Moo;
@@ -23,10 +23,16 @@ sub send {
 
     $flags //= 0;
 
+    my $length;
+    {
+        use bytes;
+        $length = length($msg);
+    };
+
     $self->check_error(
         'zmq_send',
         $self->zmq3_ffi->{zmq_send}->(
-            $self->_socket, $msg, length($msg), $flags
+            $self->_socket, $msg, $length, $flags
         )
     );
 }
@@ -50,13 +56,21 @@ sub recv {
 
     $self->check_error('zmq_msg_recv', $msg_size);
 
-    my $data_ptr    = $ffi->{zmq_msg_data}->($msg_ptr);
-    my $content_ptr = FFI::Raw::memptr($msg_size);
+    my $rv;
+    if ($msg_size) {
+        my $data_ptr    = $ffi->{zmq_msg_data}->($msg_ptr);
+        my $content_ptr = FFI::Raw::memptr($msg_size);
+
+        $ffi->{memcpy}->($content_ptr, $data_ptr, $msg_size);
+        $rv = $content_ptr->tostr($msg_size);
+    }
+    else {
+        $rv = '';
+    }
 
-    $ffi->{memcpy}->($content_ptr, $data_ptr, $msg_size);
     $ffi->{zmq_msg_close}->($msg_ptr);
 
-    return $content_ptr->tostr($msg_size);
+    return $rv;
 }
 
 sub _init_zmq3_ffi {
@@ -97,7 +111,7 @@ ZMQ::FFI::ZMQ3::Socket
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
@@ -105,7 +119,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Dylan Cali.
+This software is copyright (c) 2014 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
